@@ -4,11 +4,11 @@
 
 
 
-moPrep <- function(x, formula, subset, error.proportion, gold.standard=!missing(subset)) {
+moPrep <- function(x, formula, subset, error.proportion, gold.standard=!missing(subset), error.sd) {
   UseMethod("moPrep",x)
 }
 
-moPrep.molist <- function(x, formula, subset, error.proportion, gold.standard=FALSE) {
+moPrep.molist <- function(x, formula, subset, error.proportion, gold.standard=FALSE, error.sd) {
   m <- match.call()
   m$x <- x$data
   m[[1]] <- as.name("moPrep.default")
@@ -19,13 +19,21 @@ moPrep.molist <- function(x, formula, subset, error.proportion, gold.standard=FA
   return(x)
 }
 
-moPrep.default <- function(x, formula, subset, error.proportion, gold.standard=!missing(subset)) {
+moPrep.default <- function(x, formula, subset, error.proportion, gold.standard=!missing(subset), error.sd) {
 
   if (!missing(error.proportion) &&
       !(length(error.proportion) %in% c(1,nrow(x)))) {
     stop("The error.proportion arugment must be of length 1 or the number of rows of the data.")
   }
 
+  if (!missing(error.sd) &&
+      !(length(error.sd) %in% c(1,nrow(x)))) {
+    stop("The error.sd arugment must be of length 1 or the number of rows of the data.")
+  }
+
+  if (!missing(error.proportion) & !missing(error.sd)) {
+    stop("error.proportion and error.sd cannot be set at the same time.")
+  }
   ## parse the formula
   target.name <- formula[[2]]
   pars <- formula[[3]]
@@ -37,8 +45,8 @@ moPrep.default <- function(x, formula, subset, error.proportion, gold.standard=!
   } else {
     meanpos <- length(vnames)
   }
-  if (!exists("proxyname") && missing(error.proportion) && !gold.standard) {
-    stop("Need to specify a proxy, an error proportion, or gold-standard data.")
+  if (!exists("proxyname") && missing(error.proportion) && !gold.standard && missing(error.sd)) {
+    stop("Need to specify a proxy, an error proportion, an error variance, or gold-standard data.")
   }
 
   proxysplit <- strsplit(deparse(formula), "\\|")[[1]]
@@ -49,19 +57,31 @@ moPrep.default <- function(x, formula, subset, error.proportion, gold.standard=!
   m[[1]] <- as.name("model.frame")
   m$formula <- form
   m$error.proportion <- NULL
+  m$error.sd <- NULL
   m$gold.standard <- NULL
   m$data <- m$x
   m$x <- NULL
   mf <- eval(m, sys.frame(sys.parent()))
   if (!missing(error.proportion)) {
     if (length(error.proportion) == nrow(x)) {
-      error.proportion[eval(substitute(subset,x))]
-      gs <- mf[error.proportion == 0,]
-      mf <- mf[error.proportion != 0,]
+      if (!missing(subset)) {
+        error.proportion <- error.proportion[eval(substitute(subset,x))]
+      }
+      gs <- mf[error.proportion == 0, , drop = FALSE]
+      mf <- mf[error.proportion != 0, , drop = FALSE]
+    }
+  } else if (!missing(error.sd)) {
+    if (length(error.sd) == nrow(x)) {
+      if (!missing(subset)) {
+        error.sd <- error.sd[eval(substitute(subset,x))]
+      }
+      gs <- mf[error.sd == 0, , drop = FALSE]
+      mf <- mf[error.sd != 0, , drop = FALSE]
     }
   } else {
     gs <- mf[0,]
   }
+
   if (ncol(mf) < meanpos)
     meanpos <- ncol(mf)
   prior.mean <- mf[,meanpos]
@@ -70,6 +90,9 @@ moPrep.default <- function(x, formula, subset, error.proportion, gold.standard=!
   if (!missing(error.proportion)) {
     prior.var <- var.mm*error.proportion
   }
+  if (!missing(error.sd)) {
+    prior.var <- error.sd^2
+  }
   if (exists("proxyname")) {
     prior.var <- var.mm - cov(mf[,1],mf[,proxyname], use="complete.obs")
   }
